@@ -670,6 +670,19 @@ bool PreferencesDialog::saveToTargetConfig()
     return true;
 }
 
+bool PreferencesDialog::cancelChanges()
+{
+    SubjectLocker locker(&targetConfigM);
+
+    std::list<PrefDlgSetting*>::iterator it;
+    for (it = settingsM.begin(); it != settingsM.end(); it++)
+    {
+        if (!(*it)->cancelChanges(targetConfigM))
+            return false;
+    }
+    return true;
+}
+
 void PreferencesDialog::selectPage(int index)
 {
     if (bookctrl_1 && index >= 0 && index < (int)treeItemsM.GetCount())
@@ -708,11 +721,12 @@ void PreferencesDialog::setProperties()
 
 BEGIN_EVENT_TABLE(PreferencesDialog, wxDialog)
     EVT_BUTTON(wxID_SAVE, PreferencesDialog::OnSaveButtonClick)
+    EVT_BUTTON(wxID_CANCEL, PreferencesDialog::OnCancelButtonClick)
     EVT_TREE_SEL_CHANGED(PreferencesDialog::ID_treectrl_panes,
         PreferencesDialog::OnTreeSelChanged)
 END_EVENT_TABLE()
 
-void PreferencesDialog::OnSaveButtonClick(wxCommandEvent& WXUNUSED(event))
+void PreferencesDialog::OnSaveButtonClick(wxCommandEvent& )
 {
     wxBusyCursor wait;
     if (saveToTargetConfig()) {
@@ -721,6 +735,15 @@ void PreferencesDialog::OnSaveButtonClick(wxCommandEvent& WXUNUSED(event))
     }
 }
 
+void PreferencesDialog::OnCancelButtonClick(wxCommandEvent& )
+{
+    wxBusyCursor wait;
+    if (cancelChanges()) {
+        LocalSettings locSet;
+        EndModal(wxID_CANCEL);
+    }
+}
+
 void PreferencesDialog::OnTreeSelChanged(wxTreeEvent& event)
 {
     wxTreeItemId item = event.GetItem();
