@@ -74,11 +74,19 @@ wxString CreateDDLVisitor::getCommentOn(MetadataItem& object)
             comment << "COLUMN ";
             break;
         };
+        case ntParameter:
+        {
+            Parameter p = dynamic_cast<Parameter&>(object);
+            wxString tabname(p.getParent()->getQuotedName());
+            name = tabname << "." << name;
+            comment << "PARAMETER ";
+            break;
+        };
         case ntUDF:
             comment << "EXTERNAL FUNCTION ";
             break;
         case ntGenerator:
-            comment << "SECUENCE ";
+            comment << "SEQUENCE ";
             break;
         default:
             comment << object.getTypeName() << " ";
